
## Name

neptoon

## **What is neptoon?**

neptoon is a python tool for processing Cosmic-Ray Neutron Sensors (CRNS). CRNS estimate soil moisture at the field scale, and up to root-zone depths, by tracking changes in the number of fast neutrons found at a particular location. This is primarily due to the strong inverse relationship quantities of hydrogen atoms and fast neutrons. To have estimates of only the impact of hydrogen in soil moisture, additional processing and correction steps are required. Our understanding of the sensor continues to grow and change, which brings about an increasing number of theories and equations that can be applied. 

Neptoon is designed to facilitate the painless processing of CRNS sites, utilising the most current techniques and knowledge available. It is designed to be simple to use for those who wish to simply correct a sensor with the most current understanding, as well as full featured for researchers in the CRNS space who want to experiment and test new ideas. 


## Badges

WIP

## Visuals

WIP

## Installation

Installation of neptoon will be via pip using:

`pip install neptoon`

## Usage

WIP

## Support

daniel.power@ufz.de
martin.schroen@ufz.de

## Roadmap

WIP

## Contributing

State if you are open to contributions and what your requirements are for accepting them.

For people who want to make changes to your project, it's helpful to have some documentation on how to get started. Perhaps there is a script that they should run or some environment variables that they need to set. Make these steps explicit. These instructions could also be useful to your future self.

You can also document commands to lint the code or run tests. These steps help to ensure high code quality and reduce the likelihood that the changes inadvertently break something. Having instructions for running tests is especially helpful if it requires external setup, such as starting a Selenium server for testing in a browser.

## Authors and acknowledgment

Martin Schrön, Daniel Power

## License

MIT License

## Project status

Ongoing project currently being supported by Helmholtz Zentrum for
Research and University of Bristo
